# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.1.0

import winrt.system
from winrt import _winrt_windows_system_profile_systemmanufacturers

__all__ = [
    "OemSupportInfo",
    "SmbiosInformation",
    "SystemSupportDeviceInfo",
    "SystemSupportInfo",
]

OemSupportInfo = _winrt_windows_system_profile_systemmanufacturers.OemSupportInfo
SmbiosInformation = _winrt_windows_system_profile_systemmanufacturers.SmbiosInformation
SystemSupportDeviceInfo = _winrt_windows_system_profile_systemmanufacturers.SystemSupportDeviceInfo
SystemSupportInfo = _winrt_windows_system_profile_systemmanufacturers.SystemSupportInfo



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

Self = typing.TypeVar('Self')

@typing.final
class OemSupportInfo(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> OemSupportInfo: ...
    @_property
    def support_app_link(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def support_link(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def support_provider(self) -> str: ...

@typing.final
class SmbiosInformation_Static(type):
    @_property
    def serial_number(cls) -> str: ...

@typing.final
class SmbiosInformation(winrt.system.Object, metaclass=SmbiosInformation_Static):
    pass

@typing.final
class SystemSupportDeviceInfo(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SystemSupportDeviceInfo: ...
    @_property
    def friendly_name(self) -> str: ...
    @_property
    def operating_system(self) -> str: ...
    @_property
    def system_firmware_version(self) -> str: ...
    @_property
    def system_hardware_version(self) -> str: ...
    @_property
    def system_manufacturer(self) -> str: ...
    @_property
    def system_product_name(self) -> str: ...
    @_property
    def system_sku(self) -> str: ...

@typing.final
class SystemSupportInfo_Static(type):
    @_property
    def local_system_edition(cls) -> str: ...
    @_property
    def oem_support_info(cls) -> typing.Optional[OemSupportInfo]: ...
    @_property
    def local_device_info(cls) -> typing.Optional[SystemSupportDeviceInfo]: ...

@typing.final
class SystemSupportInfo(winrt.system.Object, metaclass=SystemSupportInfo_Static):
    pass

